Skip to contents

The function returns Shiny input object related to selected cohort that is triggered whenever cohort data filters were applied to it within filtering panel.

Usage

cb_changed(session, cohort_id, step_id = NULL)

Arguments

session

Shiny session object.

cohort_id

Id of the cohort.

step_id

Id of the step to check. When NULL (default) all the steps are checked for changes.

Details

The function is meant to be used as a trigger for Shiny render functions and observers.