The demo presents available filters and toolbox features.
demo_app(
steps = TRUE,
stats = c("pre", "post"),
run_button = "none",
feedback = TRUE,
state = TRUE,
bootstrap = 5,
enable_bookmarking = TRUE,
code = TRUE,
attrition = TRUE,
show_help = TRUE,
new_step = c("clone", "configure"),
manage_step = FALSE,
...,
run_app = TRUE
)In case of `run_app=TRUE` no return value, used for side effect which is running a Shiny application. Otherwise shinyApp object.
Set to TRUE (default) if multiple steps should be available.
Choose which statistics should be displayed for data (and some filters). Possible options are: "pre" - previous step stat, "post" - current step stats, `c("pre", "post")` - for both and NULL for no stats.
Should Run button be displayed? If so, the current step computations are run only when clicked. Three options are available "none" - no button, "local" - button displayed at each step panel, "global" - button visible in top filtering panel.
Set to TRUE (default) if feedback plots should be displayed at each filter.
Set to TRUE (default) to enable get/set state panel.
Boostrap version to be used for filtering panel. See bs_theme version argument.
Set to TRUE (default) if panel should be compatible with native shiny bookmarking.
Set to TRUE (default) to enable reproducible code panel.
Set to TRUE (default) to enable attrition plot panel.
Set to TRUE (default) to enable help buttons.
Choose which add step method should be used for creating new step. Possible options are: "clone" - copy filters from last step, "configure" - opening modal and allow to chose filters from available filters.
Set to TRUE to enable managing filters tool.
Extra parameters passed to selected cohort methods. Currently unused.
If 'TRUE' the application will run using runApp, otherwise shinyApp object is returned.
if (interactive()) {
library(shinyCohortBuilder)
demo_app(steps = FALSE)
}
if (interactive()) {
library(shinyCohortBuilder)
demo_app(run_button = "local", state = FALSE)
}
Run the code above in your browser using DataLab