Learn R Programming

shinyCohortBuilder (version 0.4.0)

scb_chart_palette: Default color palette used for filter feedback plots

Description

It's a list of the following elements:

Usage

scb_chart_palette

Arguments

Format

An object of class list of length 3.

Details

  • discrete - Discrete filter plot colors.

  • histogram - Range and date range histogram color.

  • no_data - Color used to mark missing variables on feedback plots.

The palette is used as default scb_chart_palette option, that can be overwritten with custom palettes.